[java-idp-integration-tests] branch main updated: Cleanup - shorten some class names

Tom Zeller tzeller at dragonacea.biz
Sun Sep 15 19:50:20 UTC 2024


This is an automated email from the git hooks/post-receive script.

tzeller pushed a commit to branch main
in repository java-idp-integration-tests.

View the commit online:
http://git.shibboleth.net/view/?p=java-idp-integration-tests.git;a=commit;h=792be879c700e15db9f2be2f1ecb82b3b10ac288

The following commit(s) were added to refs/heads/main by this push:
     new 792be87  Cleanup - shorten some class names
792be87 is described below

commit 792be879c700e15db9f2be2f1ecb82b3b10ac288
Author: Tom Zeller <tzeller at dragonacea.biz>
AuthorDate: Sun Sep 15 13:07:30 2024 -0500

    Cleanup - shorten some class names
    
    BaseIntegrationTest -> BaseTest
    *ServerProcess -> *Server
---
 .../{BaseIntegrationTest.java => BaseTest.java}    | 26 +++++++++++-----------
 .../idp/integration/tests/ModuleTest.java          |  2 +-
 .../idp/integration/tests/StatusTest.java          |  2 +-
 .../integration/tests/cas/CASIntegrationTest.java  |  4 ++--
 .../tests/clientstorage/ClientStorageTest.java     |  4 ++--
 .../idp/integration/tests/oidc/BaseOPTest.java     |  4 ++--
 .../tests/oidc/ConformanceSuiteContainer.java      | 12 +++++-----
 .../idp/integration/tests/oidc/RPTest.java         | 16 ++++++-------
 .../integration/tests/plugins/BasePluginTest.java  |  4 ++--
 .../tests/saml1/AbstractSAML1IntegrationTest.java  |  4 ++--
 .../tests/saml2/AbstractSAML2IntegrationTest.java  |  6 ++---
 .../saml2/SAML2AttributeQueryIntegrationTest.java  |  4 ++--
 .../tests/ui/csrf/CSRFMitigationTest.java          |  4 ++--
 ...tractServerProcess.java => AbstractServer.java} | 12 +++++-----
 .../{JettyServerProcess.java => JettyServer.java}  |  4 ++--
 ...{TomcatServerProcess.java => TomcatServer.java} | 10 ++++-----
 .../tests/util/testng/IgnoreTestIntercepter.java   |  6 ++---
 17 files changed, 62 insertions(+), 62 deletions(-)

diff --git a/src/test/java/net/shibboleth/idp/integration/tests/BaseIntegrationTest.java b/src/test/java/net/shibboleth/idp/integration/tests/BaseTest.java
similarity index 99%
rename from src/test/java/net/shibboleth/idp/integration/tests/BaseIntegrationTest.java
rename to src/test/java/net/shibboleth/idp/integration/tests/BaseTest.java
index d732627..76fbe94 100644
--- a/src/test/java/net/shibboleth/idp/integration/tests/BaseIntegrationTest.java
+++ b/src/test/java/net/shibboleth/idp/integration/tests/BaseTest.java
@@ -109,9 +109,9 @@ import org.testng.annotations.Listeners;
 
 import net.shibboleth.idp.installer.PropertiesWithComments;
 import net.shibboleth.idp.integration.tests.util.Route53Helper;
-import net.shibboleth.idp.integration.tests.util.server.AbstractServerProcess;
-import net.shibboleth.idp.integration.tests.util.server.JettyServerProcess;
-import net.shibboleth.idp.integration.tests.util.server.TomcatServerProcess;
+import net.shibboleth.idp.integration.tests.util.server.AbstractServer;
+import net.shibboleth.idp.integration.tests.util.server.JettyServer;
+import net.shibboleth.idp.integration.tests.util.server.TomcatServer;
 import net.shibboleth.idp.integration.tests.util.testng.TestNameLogger;
 import net.shibboleth.shared.annotation.constraint.NonnullAfterInit;
 import net.shibboleth.shared.annotation.constraint.NotEmpty;
@@ -133,7 +133,7 @@ import net.shibboleth.shared.xml.ParserPool;
  * 
  * <p>
  * The IdP and testbed webapps are run via Jetty's start.jar in a separate {@link Process}, see
- * {@link JettyServerProcess}.
+ * {@link JettyServer}.
  * </p>
  * 
  * <p>
@@ -175,7 +175,7 @@ import net.shibboleth.shared.xml.ParserPool;
  * </p>
  */
 @Listeners({TestNameLogger.class})
-public abstract class BaseIntegrationTest {
+public abstract class BaseTest {
 
     /** Name of property defining the address that the web server listens on. */
     @Nonnull public final static String PRIVATE_SERVER_ADDRESS_PROPERTY = "server.address.private";
@@ -247,7 +247,7 @@ public abstract class BaseIntegrationTest {
     @NonnullAfterInit protected String defaultIdpXMLSecurityManager;
 
     /** Server process. */
-    @NonnullAfterInit protected AbstractServerProcess server;
+    @NonnullAfterInit protected AbstractServer server;
 
     /** Additional commands used to start the server process. */
     @NonnullAfterInit protected List<String> serverCommands = new ArrayList<>();
@@ -429,7 +429,7 @@ public abstract class BaseIntegrationTest {
     final public String truststoresResource = "/net/shibboleth/idp/integration/tests/truststores/";
 
     /** Class logger. */
-    @Nonnull private final Logger log = LoggerFactory.getLogger(BaseIntegrationTest.class);
+    @Nonnull private final Logger log = LoggerFactory.getLogger(BaseTest.class);
 
     /**
      * Set up paths to the IdP.
@@ -1081,7 +1081,7 @@ public abstract class BaseIntegrationTest {
      * @throws Exception if an error occurs
      */
     public void startBrowser() throws Exception {
-        if (BaseIntegrationTest.isRemote()) {
+        if (BaseTest.isRemote()) {
             log.debug("Setting up remote Sauce Labs web driver");
             setUpRemoteDriver();
         } else {
@@ -1136,7 +1136,7 @@ public abstract class BaseIntegrationTest {
      * @throws ComponentInitializationException if the server cannot be initialized
      */
     public void startJettyServer() throws ComponentInitializationException {
-        server = new JettyServerProcess();
+        server = new JettyServer();
         server.setServletContainerBasePath(pathToJettyBase);
         server.setServletContainerHomePath(pathToJettyHome);
         server.setAdditionalCommands(serverCommands);
@@ -1157,7 +1157,7 @@ public abstract class BaseIntegrationTest {
      * @throws ComponentInitializationException if the server cannot be initialized
      */
     public void startTomcatServer() throws ComponentInitializationException {
-        server = new TomcatServerProcess();
+        server = new TomcatServer();
         server.setServletContainerBasePath(pathToTomcatBase);
         server.setServletContainerHomePath(pathToTomcatHome);
         server.setAdditionalCommands(serverCommands);
@@ -1303,7 +1303,7 @@ public abstract class BaseIntegrationTest {
      */
     public static void replaceFile(@Nonnull final Path pathToFile, @Nonnull @NotEmpty final String regex,
             @Nonnull @NotEmpty final String replacement) throws IOException {
-        LoggerFactory.getLogger(BaseIntegrationTest.class).debug("Replacing regex '{}' with '{}' in file '{}'", regex,
+        LoggerFactory.getLogger(BaseTest.class).debug("Replacing regex '{}' with '{}' in file '{}'", regex,
                 replacement, pathToFile);
 
         Assert.assertNotNull(pathToFile, "Path not found " + pathToFile);
@@ -1743,7 +1743,7 @@ public abstract class BaseIntegrationTest {
      */
     @BeforeClass(enabled = true)
     public void setUpSauceLabsClientIPRange() {
-        if (BaseIntegrationTest.isRemote()) {
+        if (BaseTest.isRemote()) {
             clientIPRanges.addAll(SAUCE_LABS_IP_RANGES);
             log.debug("Setting client IP range to '{}'", clientIPRanges);
         }
@@ -2643,7 +2643,7 @@ public abstract class BaseIntegrationTest {
 
             final String toUncomment = matcher.group(1);
 
-            LoggerFactory.getLogger(BaseIntegrationTest.class)
+            LoggerFactory.getLogger(BaseTest.class)
                     .debug("Replacing \n '{}' \n with \n '{}' \n in file '{}'", found, toUncomment, pathToFile);
 
             content = content.replace(found, toUncomment);
diff --git a/src/test/java/net/shibboleth/idp/integration/tests/ModuleTest.java b/src/test/java/net/shibboleth/idp/integration/tests/ModuleTest.java
index b953ecd..914f87a 100644
--- a/src/test/java/net/shibboleth/idp/integration/tests/ModuleTest.java
+++ b/src/test/java/net/shibboleth/idp/integration/tests/ModuleTest.java
@@ -22,7 +22,7 @@ import org.testng.annotations.Test;
 /**
  * Test IdP modules.
  */
-public class ModuleTest extends BaseIntegrationTest {
+public class ModuleTest extends BaseTest {
 
     /**
      * Test starting the IdP with all modules enabled.
diff --git a/src/test/java/net/shibboleth/idp/integration/tests/StatusTest.java b/src/test/java/net/shibboleth/idp/integration/tests/StatusTest.java
index 3f45513..806c815 100644
--- a/src/test/java/net/shibboleth/idp/integration/tests/StatusTest.java
+++ b/src/test/java/net/shibboleth/idp/integration/tests/StatusTest.java
@@ -23,7 +23,7 @@ import org.testng.annotations.Test;
 /**
  * Status test.
  */
-public class StatusTest extends BaseIntegrationTest {
+public class StatusTest extends BaseTest {
 
     /** Path to status page. */
     public final static String statusPath = "/idp/status";
diff --git a/src/test/java/net/shibboleth/idp/integration/tests/cas/CASIntegrationTest.java b/src/test/java/net/shibboleth/idp/integration/tests/cas/CASIntegrationTest.java
index d230555..e819dff 100644
--- a/src/test/java/net/shibboleth/idp/integration/tests/cas/CASIntegrationTest.java
+++ b/src/test/java/net/shibboleth/idp/integration/tests/cas/CASIntegrationTest.java
@@ -27,13 +27,13 @@ import org.testng.Assert;
 import org.testng.annotations.BeforeClass;
 import org.testng.annotations.Test;
 
-import net.shibboleth.idp.integration.tests.BaseIntegrationTest;
+import net.shibboleth.idp.integration.tests.BaseTest;
 import net.shibboleth.shared.primitive.StringSupport;
 
 /**
  * Simple CAS integration test.
  */
-public class CASIntegrationTest extends BaseIntegrationTest {
+public class CASIntegrationTest extends BaseTest {
 
     /** Class logger. */
     @Nonnull private final Logger log = LoggerFactory.getLogger(CASIntegrationTest.class);
diff --git a/src/test/java/net/shibboleth/idp/integration/tests/clientstorage/ClientStorageTest.java b/src/test/java/net/shibboleth/idp/integration/tests/clientstorage/ClientStorageTest.java
index 5f702da..a83960b 100644
--- a/src/test/java/net/shibboleth/idp/integration/tests/clientstorage/ClientStorageTest.java
+++ b/src/test/java/net/shibboleth/idp/integration/tests/clientstorage/ClientStorageTest.java
@@ -35,13 +35,13 @@ import org.testng.Assert;
 import org.testng.annotations.BeforeClass;
 import org.testng.annotations.Test;
 
-import net.shibboleth.idp.integration.tests.BaseIntegrationTest;
+import net.shibboleth.idp.integration.tests.BaseTest;
 import net.shibboleth.shared.annotation.constraint.NonnullAfterInit;
 
 /**
  * Client storage tests.
  */
-public class ClientStorageTest extends BaseIntegrationTest {
+public class ClientStorageTest extends BaseTest {
 
     /** Default storage service ID. */
     @Nonnull public final static String DEFAULT_STORAGE_SERIVCE_ID = "shibboleth.ClientPersistentStorageService";
diff --git a/src/test/java/net/shibboleth/idp/integration/tests/oidc/BaseOPTest.java b/src/test/java/net/shibboleth/idp/integration/tests/oidc/BaseOPTest.java
index e5eeb37..d6f53d8 100644
--- a/src/test/java/net/shibboleth/idp/integration/tests/oidc/BaseOPTest.java
+++ b/src/test/java/net/shibboleth/idp/integration/tests/oidc/BaseOPTest.java
@@ -35,7 +35,7 @@ import org.testng.Assert;
 import org.testng.annotations.AfterMethod;
 import org.testng.annotations.Listeners;
 
-import net.shibboleth.idp.integration.tests.BaseIntegrationTest;
+import net.shibboleth.idp.integration.tests.BaseTest;
 import net.shibboleth.idp.integration.tests.util.testng.IgnoreTestIntercepter;
 import net.shibboleth.shared.component.ComponentInitializationException;
 
@@ -43,7 +43,7 @@ import net.shibboleth.shared.component.ComponentInitializationException;
  * Abstract OIDC OP integration test.
  */
 @Listeners(value = IgnoreTestIntercepter.class)
-public abstract class BaseOPTest extends BaseIntegrationTest {
+public abstract class BaseOPTest extends BaseTest {
 
     /** Class logger. */
     @Nonnull
diff --git a/src/test/java/net/shibboleth/idp/integration/tests/oidc/RPTest.java b/src/test/java/net/shibboleth/idp/integration/tests/oidc/RPTest.java
index 3415db1..1127da4 100644
--- a/src/test/java/net/shibboleth/idp/integration/tests/oidc/RPTest.java
+++ b/src/test/java/net/shibboleth/idp/integration/tests/oidc/RPTest.java
@@ -49,11 +49,11 @@ import org.testng.annotations.Test;
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 
-import net.shibboleth.idp.integration.tests.BaseIntegrationTest;
+import net.shibboleth.idp.integration.tests.BaseTest;
 import net.shibboleth.idp.integration.tests.StatusTest;
-import net.shibboleth.idp.integration.tests.util.server.AbstractServerProcess;
-import net.shibboleth.idp.integration.tests.util.server.JettyServerProcess;
-import net.shibboleth.idp.integration.tests.util.server.TomcatServerProcess;
+import net.shibboleth.idp.integration.tests.util.server.AbstractServer;
+import net.shibboleth.idp.integration.tests.util.server.JettyServer;
+import net.shibboleth.idp.integration.tests.util.server.TomcatServer;
 import net.shibboleth.idp.test.flows.saml2.SAML2TestResponseValidator;
 import net.shibboleth.shared.annotation.constraint.NonnullAfterInit;
 import net.shibboleth.shared.component.ComponentInitializationException;
@@ -75,7 +75,7 @@ public class RPTest extends BaseOPTest {
 
     /** Server process for the OP. */
     @NonnullAfterInit
-    protected AbstractServerProcess opServer;
+    protected AbstractServer opServer;
 
     /** Non-secure port that the OP web server listens on. Defaults to 8081. */
     @Nonnull
@@ -802,7 +802,7 @@ public class RPTest extends BaseOPTest {
         validator = new SAML2TestResponseValidator();
         validator.spCredential = getSPCredential();
         validator.authnContextClassRef = "urn:oasis:names:tc:SAML:2.0:ac:classes:unspecified";
-        if (BaseIntegrationTest.isRemote()) {
+        if (BaseTest.isRemote()) {
             for (final String ipRange : SAUCE_LABS_IP_RANGES) {
                 validator.subjectConfirmationDataAddressRanges.add(IPRange.parseCIDRBlock(ipRange));
             }
@@ -848,7 +848,7 @@ public class RPTest extends BaseOPTest {
      *             if the server cannot be initialized
      */
     protected void startOPJettyServer() throws ComponentInitializationException {
-        opServer = new JettyServerProcess();
+        opServer = new JettyServer();
         opServer.setServletContainerBasePath(pathToOpJettyBase);
         opServer.setServletContainerHomePath(pathToJettyHome);
         opServer.setAdditionalCommands(opServerCommands);
@@ -871,7 +871,7 @@ public class RPTest extends BaseOPTest {
      *             if the server cannot be initialized
      */
     protected void startOPTomcatServer() throws ComponentInitializationException {
-        opServer = new TomcatServerProcess();
+        opServer = new TomcatServer();
         opServer.setServletContainerBasePath(pathToOpTomcatBase);
         opServer.setServletContainerHomePath(pathToTomcatHome);
         opServer.setAdditionalCommands(opServerCommands);
diff --git a/src/test/java/net/shibboleth/idp/integration/tests/plugins/BasePluginTest.java b/src/test/java/net/shibboleth/idp/integration/tests/plugins/BasePluginTest.java
index 45ed31b..d33f72e 100644
--- a/src/test/java/net/shibboleth/idp/integration/tests/plugins/BasePluginTest.java
+++ b/src/test/java/net/shibboleth/idp/integration/tests/plugins/BasePluginTest.java
@@ -23,12 +23,12 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.testng.annotations.BeforeClass;
 
-import net.shibboleth.idp.integration.tests.BaseIntegrationTest;
+import net.shibboleth.idp.integration.tests.BaseTest;
 
 /**
  * Base test class for IdP plugins.
  */
-public abstract class BasePluginTest extends BaseIntegrationTest {
+public abstract class BasePluginTest extends BaseTest {
 
     /** Class logger. */
     @Nonnull
diff --git a/src/test/java/net/shibboleth/idp/integration/tests/saml1/AbstractSAML1IntegrationTest.java b/src/test/java/net/shibboleth/idp/integration/tests/saml1/AbstractSAML1IntegrationTest.java
index 1c32394..80f9305 100644
--- a/src/test/java/net/shibboleth/idp/integration/tests/saml1/AbstractSAML1IntegrationTest.java
+++ b/src/test/java/net/shibboleth/idp/integration/tests/saml1/AbstractSAML1IntegrationTest.java
@@ -36,14 +36,14 @@ import org.testng.annotations.BeforeMethod;
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 
-import net.shibboleth.idp.integration.tests.BaseIntegrationTest;
+import net.shibboleth.idp.integration.tests.BaseTest;
 import net.shibboleth.idp.test.flows.saml1.SAML1TestResponseValidator;
 import net.shibboleth.shared.xml.XMLParserException;
 
 /**
  * Abstract SAML 1 integration test.
  */
-public class AbstractSAML1IntegrationTest extends BaseIntegrationTest {
+public class AbstractSAML1IntegrationTest extends BaseTest {
 
     /** Response validator. */
     @Nonnull protected SAML1TestResponseValidator validator;
diff --git a/src/test/java/net/shibboleth/idp/integration/tests/saml2/AbstractSAML2IntegrationTest.java b/src/test/java/net/shibboleth/idp/integration/tests/saml2/AbstractSAML2IntegrationTest.java
index 6fd03ab..de336fd 100644
--- a/src/test/java/net/shibboleth/idp/integration/tests/saml2/AbstractSAML2IntegrationTest.java
+++ b/src/test/java/net/shibboleth/idp/integration/tests/saml2/AbstractSAML2IntegrationTest.java
@@ -26,7 +26,7 @@ import java.security.cert.X509Certificate;
 import javax.annotation.Nonnull;
 import javax.annotation.Nullable;
 
-import net.shibboleth.idp.integration.tests.BaseIntegrationTest;
+import net.shibboleth.idp.integration.tests.BaseTest;
 import net.shibboleth.idp.integration.tests.StatusTest;
 import net.shibboleth.idp.test.flows.saml2.SAML2TestResponseValidator;
 import net.shibboleth.idp.test.flows.saml2.SAML2TestStatusResponseTypeValidator;
@@ -58,7 +58,7 @@ import org.w3c.dom.Element;
 /**
  * Abstract SAML 2 integration test.
  */
-public abstract class AbstractSAML2IntegrationTest extends BaseIntegrationTest {
+public abstract class AbstractSAML2IntegrationTest extends BaseTest {
 
     /** Class logger. */
     @Nonnull private final Logger log = LoggerFactory.getLogger(AbstractSAML2IntegrationTest.class);
@@ -103,7 +103,7 @@ public abstract class AbstractSAML2IntegrationTest extends BaseIntegrationTest {
         validator = new SAML2TestResponseValidator();
         validator.spCredential = getSPCredential();
         validator.authnContextClassRef = AuthnContext.PPT_AUTHN_CTX;
-        if (BaseIntegrationTest.isRemote()) {
+        if (BaseTest.isRemote()) {
             for (final String ipRange : SAUCE_LABS_IP_RANGES) {
                 validator.subjectConfirmationDataAddressRanges.add(IPRange.parseCIDRBlock(ipRange));
             }
diff --git a/src/test/java/net/shibboleth/idp/integration/tests/saml2/SAML2AttributeQueryIntegrationTest.java b/src/test/java/net/shibboleth/idp/integration/tests/saml2/SAML2AttributeQueryIntegrationTest.java
index 1b2f0f4..0c7c570 100644
--- a/src/test/java/net/shibboleth/idp/integration/tests/saml2/SAML2AttributeQueryIntegrationTest.java
+++ b/src/test/java/net/shibboleth/idp/integration/tests/saml2/SAML2AttributeQueryIntegrationTest.java
@@ -45,7 +45,7 @@ import org.testng.annotations.BeforeClass;
 import org.testng.annotations.BeforeMethod;
 import org.testng.annotations.Test;
 
-import net.shibboleth.idp.integration.tests.BaseIntegrationTest;
+import net.shibboleth.idp.integration.tests.BaseTest;
 import net.shibboleth.idp.test.flows.saml2.SAML2TestResponseValidator;
 import net.shibboleth.idp.test.flows.saml2.SAML2TestStatusResponseTypeValidator;
 import net.shibboleth.shared.annotation.constraint.NonnullAfterInit;
@@ -110,7 +110,7 @@ public class SAML2AttributeQueryIntegrationTest extends AbstractSAML2Integration
         ssoValidator = new SAML2TestResponseValidator();
         ssoValidator.spCredential = getSPCredential();
         ssoValidator.authnContextClassRef = AuthnContext.PPT_AUTHN_CTX;
-        if (BaseIntegrationTest.isRemote()) {
+        if (BaseTest.isRemote()) {
             for (final String ipRange : SAUCE_LABS_IP_RANGES) {
                 ssoValidator.subjectConfirmationDataAddressRanges.add(IPRange.parseCIDRBlock(ipRange));
             }
diff --git a/src/test/java/net/shibboleth/idp/integration/tests/ui/csrf/CSRFMitigationTest.java b/src/test/java/net/shibboleth/idp/integration/tests/ui/csrf/CSRFMitigationTest.java
index 90e38fb..32ff417 100644
--- a/src/test/java/net/shibboleth/idp/integration/tests/ui/csrf/CSRFMitigationTest.java
+++ b/src/test/java/net/shibboleth/idp/integration/tests/ui/csrf/CSRFMitigationTest.java
@@ -34,12 +34,12 @@ import org.testng.Assert;
 import org.testng.annotations.BeforeClass;
 import org.testng.annotations.Test;
 
-import net.shibboleth.idp.integration.tests.BaseIntegrationTest;
+import net.shibboleth.idp.integration.tests.BaseTest;
 
 /**
  * Test the anti-csrf token is required when submitting the username and password form.
  */
-public class CSRFMitigationTest extends BaseIntegrationTest {
+public class CSRFMitigationTest extends BaseTest {
     
     /** Class logger. */
     @Nonnull private final Logger log = LoggerFactory.getLogger(CSRFMitigationTest.class);
diff --git a/src/test/java/net/shibboleth/idp/integration/tests/util/server/AbstractServerProcess.java b/src/test/java/net/shibboleth/idp/integration/tests/util/server/AbstractServer.java
similarity index 97%
rename from src/test/java/net/shibboleth/idp/integration/tests/util/server/AbstractServerProcess.java
rename to src/test/java/net/shibboleth/idp/integration/tests/util/server/AbstractServer.java
index 318a1db..9525279 100644
--- a/src/test/java/net/shibboleth/idp/integration/tests/util/server/AbstractServerProcess.java
+++ b/src/test/java/net/shibboleth/idp/integration/tests/util/server/AbstractServer.java
@@ -65,10 +65,10 @@ import net.shibboleth.shared.primitive.StringSupport;
  * <p>
  * Waits for the IdP status page to be available.
  */
-public class AbstractServerProcess extends AbstractInitializableComponent implements Lifecycle {
+public class AbstractServer extends AbstractInitializableComponent implements Lifecycle {
 
     /** Class logger. */
-    @Nonnull private final Logger log = LoggerFactory.getLogger(AbstractServerProcess.class);
+    @Nonnull private final Logger log = LoggerFactory.getLogger(AbstractServer.class);
 
     /** Path to Servlet container base. */
     @Nonnull private Path pathToContainerBase;
@@ -230,7 +230,7 @@ public class AbstractServerProcess extends AbstractInitializableComponent implem
      * @return this server
      */
     @Nonnull
-    public AbstractServerProcess setAdditionalCommands(@Nullable final List<String> commands) {
+    public AbstractServer setAdditionalCommands(@Nullable final List<String> commands) {
         if (commands != null) {
             additionalCommands = commands;
         }
@@ -244,7 +244,7 @@ public class AbstractServerProcess extends AbstractInitializableComponent implem
      * @return this server
      */
     @Nonnull
-    public AbstractServerProcess setServletContainerBasePath(@Nonnull final Path containerBasePath) {
+    public AbstractServer setServletContainerBasePath(@Nonnull final Path containerBasePath) {
         pathToContainerBase = Constraint.isNotNull(containerBasePath, "Path to Servlet container base cannot be null");
         return this;
     }
@@ -256,7 +256,7 @@ public class AbstractServerProcess extends AbstractInitializableComponent implem
      * @return this server
      */
     @Nonnull
-    public AbstractServerProcess setServletContainerHomePath(@Nonnull final Path containerHomePath) {
+    public AbstractServer setServletContainerHomePath(@Nonnull final Path containerHomePath) {
         pathToContainerHome = Constraint.isNotNull(containerHomePath, "Path to Servlet container home cannot be null");
         return this;
     }
@@ -268,7 +268,7 @@ public class AbstractServerProcess extends AbstractInitializableComponent implem
      * @return this server
      */
     @Nonnull
-    public AbstractServerProcess setStatusPageURL(@Nonnull @NotEmpty final String URL) {
+    public AbstractServer setStatusPageURL(@Nonnull @NotEmpty final String URL) {
         statusPageURL = Constraint.isNotNull(StringSupport.trimOrNull(URL), "Status page URL cannot be null nor empty");
         return this;
     }
diff --git a/src/test/java/net/shibboleth/idp/integration/tests/util/server/JettyServerProcess.java b/src/test/java/net/shibboleth/idp/integration/tests/util/server/JettyServer.java
similarity index 98%
rename from src/test/java/net/shibboleth/idp/integration/tests/util/server/JettyServerProcess.java
rename to src/test/java/net/shibboleth/idp/integration/tests/util/server/JettyServer.java
index ec92609..1a1388a 100644
--- a/src/test/java/net/shibboleth/idp/integration/tests/util/server/JettyServerProcess.java
+++ b/src/test/java/net/shibboleth/idp/integration/tests/util/server/JettyServer.java
@@ -37,10 +37,10 @@ import net.shibboleth.shared.component.ComponentInitializationException;
 import net.shibboleth.shared.logic.Constraint;
 
 /** Start Jetty via start.jar. */
-public class JettyServerProcess extends AbstractServerProcess {
+public class JettyServer extends AbstractServer {
 
     /** Class logger. */
-    @Nonnull private final Logger log = LoggerFactory.getLogger(JettyServerProcess.class);
+    @Nonnull private final Logger log = LoggerFactory.getLogger(JettyServer.class);
 
     /** Passphrase to use to shutdown Jetty. Defaults to SHUTDOWN. */
     @Nonnull private String shutdownKey = "SHUTDOWN";
diff --git a/src/test/java/net/shibboleth/idp/integration/tests/util/server/TomcatServerProcess.java b/src/test/java/net/shibboleth/idp/integration/tests/util/server/TomcatServer.java
similarity index 93%
rename from src/test/java/net/shibboleth/idp/integration/tests/util/server/TomcatServerProcess.java
rename to src/test/java/net/shibboleth/idp/integration/tests/util/server/TomcatServer.java
index d35a00b..bf6a06f 100644
--- a/src/test/java/net/shibboleth/idp/integration/tests/util/server/TomcatServerProcess.java
+++ b/src/test/java/net/shibboleth/idp/integration/tests/util/server/TomcatServer.java
@@ -29,15 +29,15 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.testng.Assert;
 
-import net.shibboleth.idp.integration.tests.BaseIntegrationTest;
+import net.shibboleth.idp.integration.tests.BaseTest;
 import net.shibboleth.shared.component.ComponentInitializationException;
 import net.shibboleth.shared.logic.Constraint;
 
 /** Start Tomcat via 'catalina.sh run'. */
-public class TomcatServerProcess extends AbstractServerProcess {
+public class TomcatServer extends AbstractServer {
 
     /** Class logger. */
-    @Nonnull private final Logger log = LoggerFactory.getLogger(TomcatServerProcess.class);
+    @Nonnull private final Logger log = LoggerFactory.getLogger(TomcatServer.class);
 
     /** {@inheritDoc} */
     @Override
@@ -56,7 +56,7 @@ public class TomcatServerProcess extends AbstractServerProcess {
         for (final String serverCommand : getAdditionalCommands()) {
             if (serverCommand.startsWith("-D")) {
                 try {
-                    BaseIntegrationTest.replaceFile(pathToSetenvSh, "\"$", " " + Matcher.quoteReplacement(serverCommand) + "\"");
+                    BaseTest.replaceFile(pathToSetenvSh, "\"$", " " + Matcher.quoteReplacement(serverCommand) + "\"");
                 } catch (IOException e) {
                     log.error("Unable to replace file", e);
                     throw new ComponentInitializationException(e);
@@ -94,7 +94,7 @@ public class TomcatServerProcess extends AbstractServerProcess {
 
         final Path pathToCatalinaProp = getServletContainerBasePath().resolve(Paths.get("conf", "catalina.properties"));
         try {
-            BaseIntegrationTest.replaceFile(pathToCatalinaProp, "tomcat.shutdown.port=.*",
+            BaseTest.replaceFile(pathToCatalinaProp, "tomcat.shutdown.port=.*",
                     "tomcat.shutdown.port=" + Integer.toString(shutdownPort));
         } catch (IOException e) {
             log.error("Unable to replace file '{}'", pathToCatalinaProp, e);
diff --git a/src/test/java/net/shibboleth/idp/integration/tests/util/testng/IgnoreTestIntercepter.java b/src/test/java/net/shibboleth/idp/integration/tests/util/testng/IgnoreTestIntercepter.java
index 4e06479..1fac73f 100644
--- a/src/test/java/net/shibboleth/idp/integration/tests/util/testng/IgnoreTestIntercepter.java
+++ b/src/test/java/net/shibboleth/idp/integration/tests/util/testng/IgnoreTestIntercepter.java
@@ -12,7 +12,7 @@ import org.testng.IMethodInstance;
 import org.testng.IMethodInterceptor;
 import org.testng.ITestContext;
 
-import net.shibboleth.idp.integration.tests.BaseIntegrationTest;
+import net.shibboleth.idp.integration.tests.BaseTest;
 import net.shibboleth.idp.integration.tests.util.testng.annotation.IdPV5OrLater;
 import net.shibboleth.idp.integration.tests.util.testng.annotation.LinuxOnly;
 import net.shibboleth.idp.integration.tests.util.testng.annotation.OPConformance;
@@ -75,7 +75,7 @@ public class IgnoreTestIntercepter implements IMethodInterceptor {
                 .getMethod()
                 .getAnnotation(IdPV5OrLater.class);
 
-        if (idpV5Only != null && Integer.parseInt(BaseIntegrationTest.idpVersion().substring(0, 1)) < 5) {
+        if (idpV5Only != null && Integer.parseInt(BaseTest.idpVersion().substring(0, 1)) < 5) {
             return false;
         }
 
@@ -97,7 +97,7 @@ public class IgnoreTestIntercepter implements IMethodInterceptor {
                 .getMethod()
                 .getAnnotation(LinuxOnly.class);
 
-        if (linuxOnly != null && BaseIntegrationTest.isWindows()) {
+        if (linuxOnly != null && BaseTest.isWindows()) {
             return false;
         }
 

diff --git a/src/test/java/net/shibboleth/idp/integration/tests/oidc/ConformanceSuiteContainer.java b/src/test/java/net/shibboleth/idp/integration/tests/oidc/ConformanceSuiteContainer.java
index f6c90ed..269ebeb 100644
--- a/src/test/java/net/shibboleth/idp/integration/tests/oidc/ConformanceSuiteContainer.java
+++ b/src/test/java/net/shibboleth/idp/integration/tests/oidc/ConformanceSuiteContainer.java
@@ -21,7 +21,7 @@ import org.testcontainers.containers.DockerComposeContainer;
 import org.testcontainers.containers.wait.strategy.Wait;
 import org.testng.Assert;
 
-import net.shibboleth.idp.integration.tests.BaseIntegrationTest;
+import net.shibboleth.idp.integration.tests.BaseTest;
 import net.shibboleth.shared.annotation.constraint.NonnullAfterInit;
 import net.shibboleth.shared.annotation.constraint.NotEmpty;
 import net.shibboleth.shared.component.AbstractIdentifiableInitializableComponent;
@@ -93,7 +93,7 @@ public class ConformanceSuiteContainer extends AbstractIdentifiableInitializable
         // TODO "docker-compose-dev-mac.yml"
         pathToDockerComposeYML = pathToConformanceSuite.resolve("docker-compose.yml");
 
-        pathToTestDistributions = Paths.get(BaseIntegrationTest.TEST_DISTRIBUTIONS_DIRECTORY);
+        pathToTestDistributions = Paths.get(BaseTest.TEST_DISTRIBUTIONS_DIRECTORY);
 
         pathToPythonVenv = pathToTestDistributions.resolve("conformance-suite-venv");
 
@@ -366,7 +366,7 @@ public class ConformanceSuiteContainer extends AbstractIdentifiableInitializable
     /**
      * Log output of process.
      * 
      * Implemented here because {@link BaseIntegrationTest} is not the parent class.
      * 
      * @param process the process to be logged
      * @param prefix the prefix of the message to be logged
@@ -381,9 +381,9 @@ public class ConformanceSuiteContainer extends AbstractIdentifiableInitializable
     }
 
     /**
-     * See {@link BaseIntegrationTest#replaceFile(Path, String, String)}
+     * See {@link BaseTest#replaceFile(Path, String, String)}
      * 
      * Implemented here because {@link BaseIntegrationTest} is not the parent class.
      * 
      * @param pathToFile
      *            path to the file
@@ -397,7 +397,7 @@ public class ConformanceSuiteContainer extends AbstractIdentifiableInitializable
      */
     public static void replaceFile(@Nonnull final Path pathToFile, @Nonnull @NotEmpty final String regex,
             @Nonnull @NotEmpty final String replacement) throws IOException {
-        BaseIntegrationTest.replaceFile(pathToFile, regex, replacement);
+        BaseTest.replaceFile(pathToFile, regex, replacement);
     }
 
     /**
@@ -366,7 +366,7 @@ public class ConformanceSuiteContainer extends AbstractIdentifiableInitializable
      * Log output of process.
      * 
-     * Implemented here because {@link BaseIntegrationTest} is not the parent class.
+     * Implemented here because {@link BaseTest} is not the parent class.
      * 
      * @param process the process to be logged
@@ -381,9 +381,9 @@ public class ConformanceSuiteContainer extends AbstractIdentifiableInitializable
      * 
-     * Implemented here because {@link BaseIntegrationTest} is not the parent class.
+     * Implemented here because {@link BaseTest} is not the parent class.
      * 
      * @param pathToFile
-- 
To stop receiving notification emails like this one, please contact
the administrator of this repository.


More information about the commits mailing list